MethodChannelBunnyStreamFlutter class

An implementation of BunnyStreamFlutterPlatform that uses method channels.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCollection({required int libraryId, required String collectionId}) Future<Map<String, dynamic>>
override
getVideo({required int libraryId, required String videoId}) Future<Map<String, dynamic>>
override
getVideoPlayData({required int libraryId, required String videoId, String? token, int? expires}) Future<Map<String, dynamic>>
override
initialize({required String accessKey, required int libraryId, String? cdnHostname, String? token, int? expires}) Future<void>
override
listCollections({required int libraryId, int page = 1, int itemsPerPage = 100, String? search}) Future<List<Map<String, dynamic>>>
override
listVideos({required int libraryId, int page = 1, int itemsPerPage = 100, String? search, String? collectionId}) Future<List<Map<String, dynamic>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited