BunnyStreamFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BunnyStreamFlutterPlatform
Implementers

Constructors

BunnyStreamFlutterPlatform()
Constructs a BunnyStreamFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCollection({required int libraryId, required String collectionId}) Future<Map<String, dynamic>>
getVideo({required int libraryId, required String videoId}) Future<Map<String, dynamic>>
getVideoPlayData({required int libraryId, required String videoId, String? token, int? expires}) Future<Map<String, dynamic>>
initialize({required String accessKey, required int libraryId, String? cdnHostname, String? token, int? expires}) Future<void>
listCollections({required int libraryId, int page = 1, int itemsPerPage = 100, String? search}) Future<List<Map<String, dynamic>>>
listVideos({required int libraryId, int page = 1, int itemsPerPage = 100, String? search, String? collectionId}) Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BunnyStreamFlutterPlatform
The default instance of BunnyStreamFlutterPlatform to use.
getter/setter pair